@@ -14,7 +14,11 @@
 
 #pragma once
 #include <stdlib.h> 
-#include <boost/shared_array.hpp>
+#if (__cplusplus < 201402L)
+#  include <boost/shared_array.hpp>
+#else
+#  include <memory>
+#endif
 
 #if defined(__UNIX__) || defined(__STF__)
 	#define max(a,b)   (((a) > (b)) ? (a) : (b))
@@ -29,7 +33,11 @@ template<class ITEM>
 class CArrayPtr
 {
 private:    // Private data.
+#if (__cplusplus <  201402L)
    boost::shared_array<ITEM> m_pArray;
+#else
+   std::shared_ptr<ITEM> m_pArray;
+#endif
 
 private:    // Prevent copy constructors and operator=().
    CArrayPtr(const CArrayPtr &);
