@@ -408,8 +408,8 @@ void printHeader(const BundleHeader& header) {
 
 void ByteSwap(unsigned char * b, int n)
 {
-    register int i = 0;
-    register int j = n-1;
+    int i = 0;
+    int j = n-1;
     while (i<j)
     {
         std::swap(b[i], b[j]);
