@@ -25,7 +25,12 @@
 #define _STFIO_H_
 
 #include <iostream>
-#include <boost/function.hpp>
+#if (__cplusplus < 201103)
+#  include <boost/function.hpp>
+#else
+#  include <algorithm>
+#  include <functional>
+#endif
 #include <vector>
 #include <deque>
 #include <map>
