@@ -47,7 +47,7 @@
 #error You must set wxUSE_MDI_ARCHITECTURE to 1 in setup.h!
 #endif
 
-#include "../../../stfconf.h"
+#include "stfconf.h"
 #include "./app.h"
 #include "./doc.h"
 #include "./view.h"
@@ -132,7 +132,7 @@ bool wxStfApp::OnCmdLineParsed(wxCmdLineParser& parser)
 bool wxStfApp::OnInit(void)
 {
 #ifndef _STFDEBUG
-    wxLogLevel(wxLOG_FatalError);
+    wxLog::SetLogLevel(wxLOG_FatalError);
 #endif
     if (!wxApp::OnInit()) {
         std::cerr << "Could not start application" << std::endl;
@@ -864,10 +864,6 @@ wxMenuBar *wxStfApp::CreateUnifiedMenuBar(wxStfDoc* doc) {
 wxStfChildFrame *wxStfApp::CreateChildFrame(wxDocument *doc, wxView *view)
 {
     //// Make a child frame
-#ifdef __WXMAC__
-    int xpos = (GetDocCount()-1) * 16 + 64;
-    int ypos = (GetDocCount()-1) * 16 + 80;
-#endif
     wxStfChildFrame *subframe = new wxStfChildFrame(
                                                     doc, view, 
                                                     wxStaticCast(GetTopWindow(), wxStfParentFrame), wxID_ANY, doc->GetTitle(),
